@@ -26,6 +26,8 @@
 
 #include <math.h>
 
+#include <ags/i18n.h>
+
 void ags_add_recall_container_class_init(AgsAddRecallContainerClass *add_recall_container);
 void ags_add_recall_container_connectable_interface_init(AgsConnectableInterface *connectable);
 void ags_add_recall_container_init(AgsAddRecallContainer *add_recall_container);
@@ -87,7 +89,7 @@ ags_add_recall_container_get_type()
     };
 
     ags_type_add_recall_container = g_type_register_static(AGS_TYPE_TASK,
-							   "AgsAddRecallContainer\0",
+							   "AgsAddRecallContainer",
 							   &ags_add_recall_container_info,
 							   0);
 
@@ -124,9 +126,9 @@ ags_add_recall_container_class_init(AgsAddRecallContainerClass *add_recall_conta
    * 
    * Since: 0.7.117
    */
-  param_spec = g_param_spec_object("audio\0",
-				   "audio of add recall container\0",
-				   "The audio of add recall container task\0",
+  param_spec = g_param_spec_object("audio",
+				   i18n_pspec("audio of add recall container"),
+				   i18n_pspec("The audio of add recall container task"),
 				   AGS_TYPE_AUDIO,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
@@ -140,9 +142,9 @@ ags_add_recall_container_class_init(AgsAddRecallContainerClass *add_recall_conta
    * 
    * Since: 0.7.117
    */
-  param_spec = g_param_spec_object("recall-container\0",
-				   "recall container of add recall container\0",
-				   "The recall container of add recall container task\0",
+  param_spec = g_param_spec_object("recall-container",
+				   i18n_pspec("recall container of add recall container"),
+				   i18n_pspec("The recall container of add recall container task"),
 				   AGS_TYPE_RECALL_CONTAINER,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
