@@ -21,6 +21,8 @@
 
 #include <ags/object/ags_connectable.h>
 
+#include <ags/i18n.h>
+
 void ags_remove_note_class_init(AgsRemoveNoteClass *remove_note);
 void ags_remove_note_connectable_interface_init(AgsConnectableInterface *connectable);
 void ags_remove_note_init(AgsRemoveNote *remove_note);
@@ -83,7 +85,7 @@ ags_remove_note_get_type()
     };
 
     ags_type_remove_note = g_type_register_static(AGS_TYPE_TASK,
-						  "AgsRemoveNote\0",
+						  "AgsRemoveNote",
 						  &ags_remove_note_info,
 						  0);
 
@@ -120,9 +122,9 @@ ags_remove_note_class_init(AgsRemoveNoteClass *remove_note)
    * 
    * Since: 0.7.117
    */
-  param_spec = g_param_spec_object("notation\0",
-				   "notation of add note\0",
-				   "The notation of add note task\0",
+  param_spec = g_param_spec_object("notation",
+				   i18n_pspec("notation of add note"),
+				   i18n_pspec("The notation of add note task"),
 				   AGS_TYPE_NOTATION,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
@@ -136,9 +138,9 @@ ags_remove_note_class_init(AgsRemoveNoteClass *remove_note)
    * 
    * Since: 0.7.117
    */
-  param_spec = g_param_spec_uint("x\0",
-				 "offset x\0",
-				 "The x offset\0",
+  param_spec = g_param_spec_uint("x",
+				 i18n_pspec("offset x"),
+				 i18n_pspec("The x offset"),
 				 0,
 				 G_MAXUINT,
 				 0,
@@ -154,9 +156,9 @@ ags_remove_note_class_init(AgsRemoveNoteClass *remove_note)
    * 
    * Since: 0.7.117
    */
-  param_spec = g_param_spec_uint("y\0",
-				 "offset y\0",
-				 "The y offset\0",
+  param_spec = g_param_spec_uint("y",
+				 i18n_pspec("offset y"),
+				 i18n_pspec("The y offset"),
 				 0,
 				 G_MAXUINT,
 				 0,
