@@ -1256,9 +1256,6 @@ main(int argc, char **argv)
   bindtextdomain(PACKAGE, LOCALEDIR);
   textdomain(PACKAGE);
   
-  putenv("LANG=C");
-  putenv("LC_ALL=C");
-
   single_thread_enabled = FALSE;
   builtin_theme_disabled = FALSE;
   
